@@ -1,6 +1,6 @@
 package CGI::Application::ValidateRM;
 use HTML::FillInForm;
-use Data::FormValidator 2.10;
+use Data::FormValidator;
 use CGI::Carp;
 use strict;
 use vars qw($VERSION @ISA @EXPORT @EXPORT_OK);
@@ -12,33 +12,49 @@ require Exporter;
 # names by default without a very good reason. Use EXPORT_OK instead.
 # Do not simply export all your public functions/methods/constants.
 @EXPORT = qw(
+	check_rm
 	validate_rm	
 );
 
-$VERSION = '1.01';
+$VERSION = '1.02';
 
-sub validate_rm {
-	my $self = shift;
-	my $return_rm  = shift  || die 'validate_rm: missing required input argument';
-	croak "Bad argument to validate_rm: '$return_rm' is not an object method" unless $self->can($return_rm); 
-	my $profile = shift || die 'validate_rm: missing required input argument';
-	$profile->{msgs} || die 'validate_rm: profile must use msgs key';
+sub check_rm {
+     my $self = shift;
+	 my $return_rm = shift || die 'missing required return run mode';
+     my $profile_in = shift || die 'missing required profile';
 
-	my ($valid,$missing,$invalid) =  Data::FormValidator->validate($self->query, $profile);
+	# If the profile is not a hash reference, 
+	# assume it's a CGI::App method
+	my $profile;
+	if (ref $profile_in eq 'HASH') {
+		$profile = $profile_in;
+	}
+	else {
+		$profile = $self->$profile_in;
+	}
+ 
+     require Data::FormValidator;
+     my $dfv = Data::FormValidator->new({}, $self->param('dfv_defaults') );
+
+	my $r =$dfv->check($self->query,$profile);
 
-	# if there are errors, prepare an error page;
 	my $err_page;
-	if (keys %$missing or keys %$invalid) {
-		 my $return_page = $self->$return_rm({ %$missing, %$invalid, err__ => 1 }  );
+	if ($r->has_missing or $r->has_invalid) {
+		 my $return_page = $self->$return_rm($r->msgs);
 		 require HTML::FillInForm;
 		 my $fif = new HTML::FillInForm;
 		 $err_page = $fif->fill(
 			 scalarref => \$return_page,
 			 fobject => $self->query
-		 )
+		 );
 	}
-		
-	return ($valid,$err_page);
+	return ($r,$err_page);
+}
+
+sub validate_rm {
+	my $self = shift;
+	my ($r,$err_page) = $self->check_rm(@_);
+	return (scalar $r->valid,$err_page);
 }
 
 # Autoload methods go after =cut, and are processed by the autosplit program.
@@ -54,8 +70,7 @@ CGI::Application::ValidateRM - Help validate CGI::Application run modes using Da
 
  use CGI::Application::ValidateRM;
 
- my ($valid_href, $err_page) 
-	= $self->validate_rm('form_display' ,$dfv_profile_href );
+ my ($results,$err_page) = $self->check_rm('form_display','_form_profile');
   return $err_page if $err_page; 
 
 =head1 DESCRIPTION
@@ -63,50 +78,55 @@ CGI::Application::ValidateRM - Help validate CGI::Application run modes using Da
 CGI::Application::ValidateRM helps to validate web forms when using the
 CGI::Application framework and the Data::FormValidator module. 
 
-B<validate_rm> 
+=head2 check_rm
 
-This CGI::Application method takes two required arguments , as
-follows:
+This CGI::Application method takes two inputs, as follows:
 
-=over 
+=over
 
-=item 1. Name of the run mode to return with errors.
+=item Return run mode
+
+This run mode will be used to generate an error page, with the form re-filled and
+error messages in the form. This page will returned as a second output parameter.
 
 The errors will be passed in as a hash reference, which can then be handed to a
-templating system for display.  The hash will look like this:  
+templating system for display.  
 
- {
- 	err__	  => 1,
- 	err_email => '* Invalid',
- 	err_phone => '* Missing',
- }
-
-The first field is just say "We have some errors". You can check for this in
-your template system to display a general message at the top of the page.  
-
-The remaining fields should be prepared using Data::FormValidator's
+The fields should be prepared using Data::FormValidator's
 built-in support for returning error messages as a hash reference.   
-Returning the errors with a prefix, such as "err_" is recommended. 
-To use this prefix and the other defaults, add this to your Data::FormValidator
-profile:
-
-msgs => { prefix =>'' },
+See the documentation for C<msgs> in the L<Data::FormValidator::Results>
+documentation.
 
+Returning the errors with a prefix, such as "err_" is recommended. Using
+C<any_errors> is also recommended to make it easy to display a general "we have
+some errors" message.  
 
 HTML::Template users may want to pass C<die_on_bad_params=E<gt>0> to the
-HTML::Template constructor to prevent the preference of the "err_" tokens from
+HTML::Template constructor to prevent the presence of the "err_" tokens from
 triggering an error when the errors are I<not> being displayed.
 
-By default the text will be styled bold and red. This default can be overridden
-in the Data::FormValidator profile.
+=item Data::FormVaildator  profile
 
-=item 2. A hash reference to a Data::FormValidator profile.
-
-You can also put a subroutine call here, as long as the subroutine returns the
-a compatible hash reference.
+This can either be provided as a hash reference, or as the name
+of a CGI::Application method that will return such a hash reference.
 
 =back
 
+Additionally, the value of the 'dfv_defaults' param from the calling
+object is optionally used to pass deftauls to the C<new()> constructor.
+
+  $self->param('dfv_defaults')
+
+By setting this to a hash reference of defaults in your C<cgiapp_init> routine
+in your own super-class, you could make it easy to share some default settings for
+Data::FormValidator across several forms. Of course, you could also set parameter
+through an instance script. 
+
+=head2 validate_rm 
+
+Works like C<check_rm> above, but returns the old style C<$valid> hash
+reference instead of the results object.
+
 =head1 EXAMPLE
 
 In a CGI::Application module:
@@ -127,11 +147,14 @@ In a CGI::Application module:
  	my $self = shift;
  
  	use CGI::Application::ValidateRM;
- 	my ($valid_href, $err_page) = $self->validate_rm('form_display', _form_profile() );
+ 	my ($results, $err_page) = $self->check_rm('form_display','_form_profile');
  	return $err_page if $err_page; 
+
+	#..  do something with DFV $results object now
  
  	my $t = $self->load_tmpl('success.html');
  	return $t->output;
+
  }
  
  sub _form_profile {
